Welcome to the RAUC hawkBit Client Documentation!
=================================================

The RAUC hawkBit client is a simple python-based application and library that
runs on your target and operates as an interface between the
`RAUC <https://github.com/rauc/rauc>`_ D-Bus API
and the `hawkBit <https://github.com/eclipse/hawkbit>`_ DDI API.

.. toctree::
   contributing
   changes
   modules/modules
   :maxdepth: 2
   :caption: Contents


Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
